@@ -1,3 +1,3 @@
-from parser import RobotFile, Testcase, Keyword, Row, Statement
+from parser import ResourceFile, SuiteFile, RobotFileFactory, Testcase, Keyword, Row, Statement
 from tables import DefaultTable, SettingTable, UnknownTable, VariableTable, MetadataTable, RobotTable
 
