@@ -27,6 +27,24 @@ from testcase import Testcase
 from rfkeyword import Keyword
 from common import Row, Statement
 
+def RobotFileFactory(path, parent=None):
+    '''Return an instance of SuiteFile or ResourceFile
+
+    Exactly which is returned depends on the contents of the
+    file. If there is a testcase table, this will return an
+    instance of SuiteFile, otherwise it will return an
+    instance of ResourceFile.
+    '''
+    rf = RobotFile(path, parent)
+
+    for table in rf.tables:
+        if isinstance(table, TestcaseTable):
+            rf.__class__ = SuiteFile
+            return rf
+
+    rf.__class__ = ResourceFile
+    return rf
+    
 class RobotFile(object):
     '''
     Terminology:
@@ -49,6 +67,7 @@ class RobotFile(object):
 
         self._load(path)
 
+
     def _load(self, path):
 
         '''
@@ -70,7 +89,7 @@ class RobotFile(object):
                 # this mimics what the robot TSV reader does --
                 # it replaces non-breaking spaces with regular spaces,
                 # and strips trailing whitespace
-                raw_text.replace(u'\xA0', ' ')
+                raw_text = raw_text.replace(u'\xA0', ' ')
                 raw_text = raw_text.rstrip()
 
                 # FIXME: I'm keeping line numbers but throwing away
@@ -175,6 +194,14 @@ def tableFactory(parent, linenumber, name):
     return table
 
 
+class SuiteFile(RobotFile):
+    def __repr__(self):
+        return "<SuiteFile(%s)>" % self.path
+
+class ResourceFile(RobotFile):
+    def __repr__(self):
+        return "<ResourceFile(%s)>" % self.path
+
 class TestcaseTable(AbstractContainerTable):
     _childClass = Testcase
     def __init__(self, parent, *args, **kwargs):
